@@ -8,7 +8,10 @@ import (
 	"github.com/abiosoft/colima/config"
 	"github.com/abiosoft/colima/daemon/process"
 	"github.com/abiosoft/colima/daemon/process/gvproxy"
+	"github.com/abiosoft/colima/daemon/process/inotify"
 	"github.com/abiosoft/colima/daemon/process/vmnet"
+	"github.com/abiosoft/colima/environment/host"
+	"github.com/abiosoft/colima/environment/vm/lima"
 	"github.com/spf13/cobra"
 )
 
@@ -35,6 +38,16 @@ var startCmd = &cobra.Command{
 		if daemonArgs.gvproxy.enabled {
 			processes = append(processes, gvproxy.New(daemonArgs.gvproxy.dnsHosts))
 		}
+		if daemonArgs.inotify.enabled {
+			processes = append(processes, inotify.New())
+			guest := lima.New(host.New())
+			args := inotify.Args{
+				GuestActions: guest,
+				Runtime:      daemonArgs.inotify.runtime,
+				Dirs:         daemonArgs.inotify.dirs,
+			}
+			ctx = context.WithValue(ctx, inotify.CtxKeyArgs(), args)
+		}
 
 		return start(ctx, processes)
 	},
@@ -75,7 +88,11 @@ var daemonArgs struct {
 		enabled  bool
 		dnsHosts map[string]string
 	}
-	fsnotify bool
+	inotify struct {
+		enabled bool
+		dirs    []string
+		runtime string
+	}
 
 	verbose bool
 }
@@ -89,6 +106,8 @@ func init() {
 
 	startCmd.Flags().BoolVar(&daemonArgs.vmnet, "vmnet", false, "start vmnet")
 	startCmd.Flags().BoolVar(&daemonArgs.gvproxy.enabled, "gvproxy", false, "start gvproxy")
-	startCmd.Flags().StringToStringVar(&daemonArgs.gvproxy.dnsHosts, "gvproxy-hosts", nil, "start gvproxy")
-	startCmd.Flags().BoolVar(&daemonArgs.fsnotify, "fsnotify", false, "start fsnotify")
+	startCmd.Flags().StringToStringVar(&daemonArgs.gvproxy.dnsHosts, "gvproxy-hosts", nil, "DNS hosts for gvproxy")
+	startCmd.Flags().BoolVar(&daemonArgs.inotify.enabled, "inotify", false, "start inotify")
+	startCmd.Flags().StringSliceVar(&daemonArgs.inotify.dirs, "inotify-dir", nil, "set inotify directories")
+	startCmd.Flags().StringVar(&daemonArgs.inotify.runtime, "inotify-runtime", "docker", "set runtime")
 }
