@@ -6,6 +6,7 @@ import (
 	"path/filepath"
 	"sync"
 
+	"github.com/abiosoft/colima/util"
 	"github.com/abiosoft/colima/util/fsutil"
 	"github.com/abiosoft/colima/util/osutil"
 	"github.com/abiosoft/colima/util/shautil"
@@ -40,18 +41,49 @@ func (r *requiredDir) Dir() string {
 }
 
 var (
-	configDir = requiredDir{
+	configBaseDir = requiredDir{
 		dir: func() (string, error) {
 			dir, err := os.UserHomeDir()
 			if err != nil {
 				return "", err
 			}
-			return filepath.Join(dir, ".colima", profile.ShortName), nil
+			dir = filepath.Join(dir, ".colima")
+			_, err = os.Stat(dir)
+			// TODO: remove macOS when QEMU_SYSTEM_ARCH is handled properly upstream.
+			if err == nil || util.MacOS() {
+				return dir, nil
+			}
+			// else
+			dir = os.Getenv("XDG_CONFIG_HOME")
+			if dir != "" {
+				return filepath.Join(dir, "colima"), nil
+			}
+			// else
+			dir, err = os.UserConfigDir()
+			if err != nil {
+				return "", err
+			}
+			return filepath.Join(dir, "colima"), nil
+		},
+	}
+
+	configDir = requiredDir{
+		dir: func() (string, error) {
+			dir, err := configBaseDir.dir()
+			if err != nil {
+				return "", err
+			}
+			return filepath.Join(dir, profile.ShortName), nil
 		},
 	}
 
 	cacheDir = requiredDir{
 		dir: func() (string, error) {
+			dir := os.Getenv("XDG_CACHE_HOME")
+			if dir != "" {
+				return filepath.Join(dir, "colima"), nil
+			}
+			// else
 			dir, err := os.UserCacheDir()
 			if err != nil {
 				return "", err
@@ -62,23 +94,23 @@ var (
 
 	templatesDir = requiredDir{
 		dir: func() (string, error) {
-			dir, err := os.UserHomeDir()
+			dir, err := configBaseDir.dir()
 			if err != nil {
 				return "", err
 			}
-			return filepath.Join(dir, ".colima", "_templates"), nil
+			return filepath.Join(dir, "_templates"), nil
 		},
 	}
 
 	wrapperDir = requiredDir{
 		dir: func() (string, error) {
-			dir, err := os.UserHomeDir()
+			dir, err := configBaseDir.dir()
 			if err != nil {
 				return "", err
 			}
 			// generate unique directory for the current binary
 			uniqueDir := shautil.SHA1(osutil.Executable())
-			return filepath.Join(dir, ".colima", "_wrapper", uniqueDir.String()), nil
+			return filepath.Join(dir, "_wrapper", uniqueDir.String()), nil
 		},
 	}
 )
@@ -101,3 +133,6 @@ func WrapperDir() string { return wrapperDir.Dir() }
 const ConfigFileName = "colima.yaml"
 
 func configFile() string { return filepath.Join(configDir.Dir(), ConfigFileName) }
+
+// SSHConfigFile returns the path to generated ssh config.
+func SSHConfigFile() string { return filepath.Join(filepath.Dir(configDir.Dir()), "ssh_config") }
