@@ -8,18 +8,20 @@ import (
 	"github.com/abiosoft/colima/config"
 	"github.com/abiosoft/colima/daemon/process"
 	"github.com/abiosoft/colima/daemon/process/gvproxy"
+	"github.com/abiosoft/colima/daemon/process/inotify"
 	"github.com/abiosoft/colima/daemon/process/vmnet"
 	"github.com/abiosoft/colima/environment"
+	"github.com/abiosoft/colima/util"
 	"github.com/abiosoft/colima/util/fsutil"
 	"github.com/abiosoft/colima/util/osutil"
 )
 
 // Manager handles running background processes.
 type Manager interface {
-	Start(context.Context) error
-	Stop(context.Context) error
-	Running(ctx context.Context) (Status, error)
-	Dependencies(ctx context.Context) (deps process.Dependency, root bool)
+	Start(context.Context, config.Config) error
+	Stop(context.Context, config.Config) error
+	Running(context.Context, config.Config) (Status, error)
+	Dependencies(context.Context, config.Config) (deps process.Dependency, root bool)
 }
 
 type Status struct {
@@ -49,8 +51,8 @@ type processManager struct {
 	host environment.HostActions
 }
 
-func (l processManager) Dependencies(ctx context.Context) (deps process.Dependency, root bool) {
-	processes := processesFromCtx(ctx)
+func (l processManager) Dependencies(ctx context.Context, conf config.Config) (deps process.Dependency, root bool) {
+	processes := processesFromConfig(conf)
 	return process.Dependencies(processes...)
 }
 
@@ -62,14 +64,16 @@ func (l processManager) init() error {
 	return nil
 }
 
-func (l processManager) Running(ctx context.Context) (s Status, err error) {
+func (l processManager) Running(ctx context.Context, conf config.Config) (s Status, err error) {
 	err = l.host.RunQuiet(osutil.Executable(), "daemon", "status", config.CurrentProfile().ShortName)
 	if err != nil {
 		return
 	}
 	s.Running = true
 
-	for _, p := range processesFromCtx(ctx) {
+	ctx = context.WithValue(ctx, process.CtxKeyDaemon(), s.Running)
+
+	for _, p := range processesFromConfig(conf) {
 		pErr := p.Alive(ctx)
 		s.Processes = append(s.Processes, processStatus{
 			Name:    p.Name(),
@@ -80,73 +84,63 @@ func (l processManager) Running(ctx context.Context) (s Status, err error) {
 	return
 }
 
-func (l processManager) Start(ctx context.Context) error {
-	_ = l.Stop(ctx) // this is safe, nothing is done when not running
+func (l processManager) Start(ctx context.Context, conf config.Config) error {
+	_ = l.Stop(ctx, conf) // this is safe, nothing is done when not running
 
 	if err := l.init(); err != nil {
 		return fmt.Errorf("error preparing network directory: %w", err)
 	}
 
 	args := []string{osutil.Executable(), "daemon", "start", config.CurrentProfile().ShortName}
-	opts := optsFromCtx(ctx)
-	if opts.Vmnet {
+
+	if conf.Network.Address {
 		args = append(args, "--vmnet")
 	}
-	if opts.GVProxy.Enabled {
+	if conf.MountINotify {
+		args = append(args, "--inotify")
+		args = append(args, "--inotify-runtime", conf.Runtime)
+		for _, mount := range conf.MountsOrDefault() {
+			p, err := util.CleanPath(mount.Location)
+			if err != nil {
+				return fmt.Errorf("error sanitising mount path for inotify: %w", err)
+			}
+			args = append(args, "--inotify-dir", p)
+		}
+	}
+	if conf.Network.Driver == gvproxy.Name {
 		args = append(args, "--gvproxy")
-		if len(opts.GVProxy.Hosts) > 0 {
-			for host, ip := range opts.GVProxy.Hosts {
+		if len(conf.Network.DNSHosts) > 0 {
+			for host, ip := range conf.Network.DNSHosts {
 				args = append(args, "--gvproxy-hosts", host+"="+ip)
 			}
 		}
 	}
 
 	if cli.Settings.Verbose {
-		args = append(args, "--verbose")
+		args = append(args, "--very-verbose")
 	}
 
-	return l.host.RunQuiet(args...)
+	host := l.host.WithDir(util.HomeDir())
+	return host.RunQuiet(args...)
 }
-func (l processManager) Stop(ctx context.Context) error {
-	if s, err := l.Running(ctx); err != nil || !s.Running {
+func (l processManager) Stop(ctx context.Context, conf config.Config) error {
+	if s, err := l.Running(ctx, conf); err != nil || !s.Running {
 		return nil
 	}
 	return l.host.RunQuiet(osutil.Executable(), "daemon", "stop", config.CurrentProfile().ShortName)
 }
 
-func optsFromCtx(ctx context.Context) struct {
-	Vmnet   bool
-	GVProxy struct {
-		Enabled bool
-		Hosts   map[string]string
-	}
-	FSNotify bool
-} {
-	var opts = struct {
-		Vmnet   bool
-		GVProxy struct {
-			Enabled bool
-			Hosts   map[string]string
-		}
-
-		FSNotify bool
-	}{}
-	opts.Vmnet, _ = ctx.Value(CtxKey(vmnet.Name)).(bool)
-	opts.GVProxy.Enabled, _ = ctx.Value(CtxKey(gvproxy.Name)).(bool)
-	opts.GVProxy.Hosts, _ = ctx.Value(CtxKey(gvproxy.CtxKeyHosts)).(map[string]string)
-
-	return opts
-}
-
-func processesFromCtx(ctx context.Context) []process.Process {
+func processesFromConfig(conf config.Config) []process.Process {
 	var processes []process.Process
 
-	opts := optsFromCtx(ctx)
-	if opts.Vmnet {
+	if conf.Network.Address {
 		processes = append(processes, vmnet.New())
 	}
-	if opts.GVProxy.Enabled {
-		processes = append(processes, gvproxy.New(opts.GVProxy.Hosts))
+	if conf.Network.Driver == gvproxy.Name {
+		processes = append(processes, gvproxy.New(conf.Network.DNSHosts))
+	}
+	if conf.MountINotify {
+		processes = append(processes, inotify.New())
 	}
 
 	return processes
